![clinlp logo](../../media/clinlp.png)

Welcome to the documentation pages for `clinlp`, a Python library for performing NLP on clinical text written in Dutch. In the menu to the left, you should be able to find the information you are looking for. If you have any questions, need help getting started, found a bug, or have a feature request, please don't hesitate to [contact us](contributing.md#contact)!

## Links

- [GitHub repository](https://github.com/umcu/clinlp)

```{toctree}
:caption: clinlp
:hidden:
Introduction <introduction>
Installation <installation>
Getting started <getting_started>
Roadmap <roadmap>
Apps <apps>
Data <data>
Citing <citing>
```

```{toctree}
:caption: Usage
:hidden:
Components <components>
Metrics <metrics>
```

```{toctree}
:caption: Standards
:hidden:
Qualifiers <qualifiers>
```

```{toctree}
:caption: Search & index
:hidden:

General index <genindex>
Module index <modindex>

```

```{toctree}
:caption: Development
:hidden:

API <api/api>
Contributing <contributing>
Changelog <changelog>
```
